@@ -12,8 +12,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import six
-
 from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 
@@ -71,8 +69,8 @@ class ExecuteForm(forms.SelfHandlingForm):
             messages.success(request, msg)
 
             return True
-        except Exception as e:
-            msg = _('Failed to execute workflow "%s".') % e
+        except Exception:
+            msg = _('Failed to execute workflow.')
             redirect = reverse('horizon:mistral:workflows:index')
             exceptions.handle(request, msg, redirect=redirect)
 
@@ -131,7 +129,7 @@ class DefinitionForm(forms.SelfHandlingForm):
                 cleaned_data['definition']
             )
         except Exception as e:
-            raise forms.ValidationError(six.text_type(e))
+            raise forms.ValidationError(str(e))
 
         if not validated.get('valid'):
             raise forms.ValidationError(
@@ -161,8 +159,8 @@ class CreateForm(forms.SelfHandlingForm):
             messages.success(request, msg)
 
             return True
-        except Exception as e:
-            msg = _('Failed to create workflow: %s') % e
+        except Exception:
+            msg = _('Failed to create workflow.')
             redirect = reverse('horizon:mistral:workflows:index')
             exceptions.handle(request, msg, redirect=redirect)
 
@@ -176,7 +174,7 @@ class UpdateForm(CreateForm):
             messages.success(request, msg)
 
             return True
-        except Exception as e:
-            msg = _('Failed to update workflow: %s') % e
+        except Exception:
+            msg = _('Failed to update workflow.')
             redirect = reverse('horizon:mistral:workflows:index')
             exceptions.handle(request, msg, redirect=redirect)
